===================================
Becoming a Yorkshireman (or woman!)
===================================

.. epigraph::

   If you want to go fast, go alone. If you want to go far, go together.

   -- African proverb

This is a big project, and I need plenty of help!

.. toctree::
   :maxdepth: 1

   Code of Conduct <conduct>
   Your development environment <development>
   Contributing Code <code>
   Contributing Words <words>
   Contributing Art <art>
